@@ -8,8 +8,8 @@ sub new {
 	my ($class, $name) = @_;
         my $self = $class->SUPER::new;
 
-	$self->{tokens}[Cobol::Compiler::ProgramToken->IDENTIFCATION] = 10;
-	$self->{tokens}[Cobol::Compiler::ProgramToken->PROGRAM-ID] = 20;
+	$self->{subTokens}[Cobol::Compiler::ProgramToken->IDENTIFCATION] = 11;
+	$self->{subTokens}[Cobol::Compiler::ProgramToken->PROGRAM-ID] = 21;
 
 }
 
