@@ -3,7 +3,7 @@ package Cobol::Compiler::Token;
 sub new {
 	my ($class) = @_;
 
-	my $self = { tokens => {}, };
+	my $self = { subTokens => {}, };
 
 	$class = ref($class) || $class;
 
